CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
60 lines
2.6 KiB
C++
60 lines
2.6 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip/hip_runtime.h>
|
|
|
|
#define HIP_CHECK(error) \
|
|
{ \
|
|
hipError_t localError = error; \
|
|
if ((localError != hipSuccess) && (localError != hipErrorPeerAccessAlreadyEnabled)) { \
|
|
printf("error: '%s'(%d) from %s at %s:%d\n", hipGetErrorString(localError), localError, \
|
|
#error, __FUNCTION__, __LINE__); \
|
|
return -1; \
|
|
} \
|
|
}
|
|
|
|
#define REQUIRE(res) \
|
|
{ \
|
|
if (res) { \
|
|
return 0; \
|
|
} else { \
|
|
return -1; \
|
|
} \
|
|
}
|
|
|
|
/*
|
|
* This funtion perform the below operations,
|
|
* 1) Get the Minimum Scratch limit and validate
|
|
* 2) Get the Maximum Scratch limit and validate
|
|
* 3) Get the Current Scratch limit and validate
|
|
* 4) Set the Current Scratch limit to 50% of Maximum Scratch limit
|
|
* 5) Get the Current Scratch limit and validate it
|
|
* 6) Set the Current Scratch limit to original value
|
|
*/
|
|
int main() {
|
|
size_t min = 0, max = 0, orgCurrent = 0;
|
|
|
|
HIP_CHECK(hipDeviceGetLimit(&min, hipExtLimitScratchMin));
|
|
REQUIRE(min == 0);
|
|
|
|
HIP_CHECK(hipDeviceGetLimit(&max, hipExtLimitScratchMax));
|
|
REQUIRE(max > 0);
|
|
|
|
HIP_CHECK(hipDeviceGetLimit(&orgCurrent, hipExtLimitScratchCurrent));
|
|
REQUIRE(orgCurrent >= 0);
|
|
|
|
size_t setCurrent = 0.5 * max;
|
|
HIP_CHECK(hipDeviceSetLimit(hipExtLimitScratchCurrent, setCurrent));
|
|
|
|
size_t getCurrent = 0;
|
|
HIP_CHECK(hipDeviceGetLimit(&getCurrent, hipExtLimitScratchCurrent));
|
|
REQUIRE(getCurrent == setCurrent);
|
|
|
|
HIP_CHECK(hipDeviceSetLimit(hipExtLimitScratchCurrent, orgCurrent));
|
|
|
|
return 0;
|
|
}
|